==> edeposit.amqp-1.8.6.tar.gz: edeposit.amqp-1.8.6/bin/edeposit_amqp_marcxml2modsd.py <==
#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Interpreter version: python 2.7
#
# Imports =====================================================================
"""
AMQP binding for marcxml2mods convertor. See `edeposit.amqp.marcxml2mods
<https://github.com/edeposit/edeposit.amqp.marcxml2mods>`_ for details.
"""
import os
import sys
import os.path
import argparse


from pika.exceptions import ConnectionClosed

from edeposit.amqp.marcxml2mods import *


# if the amqp module wasn't yet installed at this system, load it from package
try:
    from edeposit.amqp import settings
except ImportError:
    sys.path.insert(0, os.path.abspath('../edeposit/'))
    import amqp
    sys.modules["edeposit.amqp"] = amqp


from edeposit.amqp.amqpdaemon import AMQPDaemon, getConParams
from edeposit.amqp import settings


# Functions & objects =========================================================
def main(args, stop=False):
    """
    Arguments parsing, etc..
    """
    daemon = AMQPDaemon(
        con_param=getConParams(
            settings.RABBITMQ_MX2MOD_VIRTUALHOST
        ),
        queue=settings.RABBITMQ_MX2MOD_INPUT_QUEUE,
        out_exch=settings.RABBITMQ_MX2MOD_EXCHANGE,
        out_key=settings.RABBITMQ_MX2MOD_OUTPUT_KEY,
        react_fn=reactToAMQPMessage,
        glob=globals()                # used in deserializer
    )

    if not stop and args and args.foreground:  # run at foreground
        daemon.run()
    else:
        daemon.run_daemon()  # run as daemon


# Main program ================================================================
if __name__ == '__main__':
    if len(sys.argv) > 1 and sys.argv[1] == "stop":
        main(None, stop=True)
        sys.exit(0)

    parser = argparse.ArgumentParser(
        usage='%(prog)s start/stop/restart [-f/--foreground]',
        description="""AMQP binding for marcxml2mods subsystem."""
    )
    parser.add_argument(
        "action",
        metavar="start/stop/restart",
        type=str,
        default=None,
        help="Start/stop/restart the daemon."
    )
    parser.add_argument(
        "-f",
        '--foreground',
        action="store_true",
        required=False,
        help="""Run at foreground, not as daemon. If not set, script is will
                run at background as unix daemon."""
    )
    args = parser.parse_args()

    try:
        main(args)
    except ConnectionClosed as e:
        sys.stderr.write(
            e.message + " - is the RabbitMQ queues properly set?\n"
        )
        sys.exit(1)
    except KeyboardInterrupt:
        pass

==> edeposit.amqp-1.8.16.tar.gz: edeposit.amqp-1.8.16/bin/edeposit_amqp_marcxml2modsd.py <==
#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Interpreter version: python 2.7
#
# Imports =====================================================================
"""
AMQP binding for marcxml2mods convertor. See `edeposit.amqp.marcxml2mods
<https://github.com/edeposit/edeposit.amqp.marcxml2mods>`_ for details.
"""
import os
import sys
import os.path
import argparse


from pika.exceptions import ConnectionClosed

from edeposit.amqp.marcxml2mods import *


# if the amqp module wasn't yet installed at this system, load it from package
try:
    from edeposit.amqp import settings
except ImportError:
    sys.path.insert(0, os.path.abspath('../edeposit/'))
    import amqp
    sys.modules["edeposit.amqp"] = amqp


from edeposit.amqp.amqpdaemon import AMQPDaemon, getConParams
from edeposit.amqp import settings


# Functions & objects =========================================================
def main(args, stop=False):
    """
    Arguments parsing, etc..
    """
    daemon = AMQPDaemon(
        con_param=getConParams(
            settings.RABBITMQ_MX2MODS_VIRTUALHOST
        ),
        queue=settings.RABBITMQ_MX2MODS_INPUT_QUEUE,
        out_exch=settings.RABBITMQ_MX2MODS_EXCHANGE,
        out_key=settings.RABBITMQ_MX2MODS_OUTPUT_KEY,
        react_fn=reactToAMQPMessage,
        glob=globals()                # used in deserializer
    )

    if not stop and args and args.foreground:  # run at foreground
        daemon.run()
    else:
        daemon.run_daemon()  # run as daemon


# Main program ================================================================
if __name__ == '__main__':
    if len(sys.argv) > 1 and sys.argv[1] == "stop":
        main(None, stop=True)
        sys.exit(0)

    parser = argparse.ArgumentParser(
        usage='%(prog)s start/stop/restart [-f/--foreground]',
        description="""AMQP binding for marcxml2mods subsystem."""
    )
    parser.add_argument(
        "action",
        metavar="start/stop/restart",
        type=str,
        default=None,
        help="Start/stop/restart the daemon."
    )
    parser.add_argument(
        "-f",
        '--foreground',
        action="store_true",
        required=False,
        help="""Run at foreground, not as daemon. If not set, script is will
                run at background as unix daemon."""
    )
    args = parser.parse_args()

    try:
        main(args)
    except ConnectionClosed as e:
        sys.stderr.write(
            e.message + " - is the RabbitMQ queues properly set?\n"
        )
        sys.exit(1)
    except KeyboardInterrupt:
        pass
